==========
veryscrape
==========


.. image:: https://img.shields.io/pypi/v/veryscrape.svg
        :target: https://pypi.python.org/pypi/veryscrape

.. image:: https://img.shields.io/travis/sentrip/veryscrape.svg
        :target: https://travis-ci.org/sentrip/veryscrape

.. image:: https://readthedocs.org/projects/veryscrape/badge/?version=latest
        :target: https://veryscrape.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://codecov.io/gh/sentrip/veryscrape/branch/master/graph/badge.svg
     :target: https://codecov.io/gh/sentrip/veryscrape

.. image:: https://pyup.io/repos/github/sentrip/veryscrape/shield.svg
     :target: https://pyup.io/repos/github/sentrip/veryscrape/
     :alt: Updates



Simple time-series streaming of social media data


* Free software: GNU General Public License v3
* Documentation: https://veryscrape.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
